==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Classes/classllarp_1_1apple_1_1RouteManager.md <==
---
title: llarp::apple::RouteManager

---

# llarp::apple::RouteManager





Inherits from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)

## Public Functions

|                | Name           |
| -------------- | -------------- |
| | **[RouteManager](Classes/classllarp_1_1apple_1_1RouteManager.md#function-routemanager)**(llarp::Context & ctx, llarp_route_callbacks rcs, void * callback_context) |
| virtual void | **[AddRoute](Classes/classllarp_1_1apple_1_1RouteManager.md#function-addroute)**(IPVariant_t ip, IPVariant_t gateway) override<br>These are called for poking route holes, but we don't have to do that at all on macos because the appex isn't subject to its own rules.  |
| virtual void | **[DelRoute](Classes/classllarp_1_1apple_1_1RouteManager.md#function-delroute)**(IPVariant_t ip, IPVariant_t gateway) override |
| virtual void | **[AddDefaultRouteViaInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-adddefaultrouteviainterface)**(std::string ifname) override |
| virtual void | **[DelDefaultRouteViaInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-deldefaultrouteviainterface)**(std::string ifname) override |
| virtual void | **[AddRouteViaInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-addrouteviainterface)**([vpn::NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn, [IPRange](Classes/structllarp_1_1IPRange.md) range) override |
| virtual void | **[DelRouteViaInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-delrouteviainterface)**([vpn::NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn, [IPRange](Classes/structllarp_1_1IPRange.md) range) override |
| virtual std::vector< IPVariant_t > | **[GetGatewaysNotOnInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-getgatewaysnotoninterface)**(std::string ifname) override |

## Additional inherited members

**Public Types inherited from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)**

|                | Name           |
| -------------- | -------------- |
| using std::variant< [huint32_t](Classes/structllarp_1_1huint__t.md), [huint128_t](Classes/structllarp_1_1huint__t.md) > | **[IPVariant_t](Classes/classllarp_1_1vpn_1_1IRouteManager.md#using-ipvariant-t)**  |

**Public Functions inherited from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)**

|                | Name           |
| -------------- | -------------- |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**() =default |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**(const [IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md) & ) =delete |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**([IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md) && ) =delete |
| virtual | **[~IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-~iroutemanager)**() =default |
| virtual void | **[AddBlackhole](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addblackhole)**() |
| virtual void | **[DelBlackhole](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delblackhole)**() |


## Public Functions Documentation

### function RouteManager

```cpp
inline RouteManager(
    llarp::Context & ctx,
    llarp_route_callbacks rcs,
    void * callback_context
)
```


### function AddRoute

```cpp
inline virtual void AddRoute(
    IPVariant_t ip,
    IPVariant_t gateway
) override
```

These are called for poking route holes, but we don't have to do that at all on macos because the appex isn't subject to its own rules. 

**Reimplements**: [llarp::vpn::IRouteManager::AddRoute](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addroute)


### function DelRoute

```cpp
inline virtual void DelRoute(
    IPVariant_t ip,
    IPVariant_t gateway
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelRoute](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delroute)


### function AddDefaultRouteViaInterface

```cpp
virtual void AddDefaultRouteViaInterface(
    std::string ifname
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-adddefaultrouteviainterface)


### function DelDefaultRouteViaInterface

```cpp
virtual void DelDefaultRouteViaInterface(
    std::string ifname
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-deldefaultrouteviainterface)


### function AddRouteViaInterface

```cpp
virtual void AddRouteViaInterface(
    vpn::NetworkInterface & vpn,
    IPRange range
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addrouteviainterface)


### function DelRouteViaInterface

```cpp
virtual void DelRouteViaInterface(
    vpn::NetworkInterface & vpn,
    IPRange range
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delrouteviainterface)


### function GetGatewaysNotOnInterface

```cpp
inline virtual std::vector< IPVariant_t > GetGatewaysNotOnInterface(
    std::string ifname
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::GetGatewaysNotOnInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-getgatewaysnotoninterface)


-------------------------------

Updated on 2022-05-31 at 02:25:19 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Classes/classllarp_1_1apple_1_1RouteManager.md <==
---
title: llarp::apple::RouteManager

---

# llarp::apple::RouteManager





Inherits from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)

## Public Functions

|                | Name           |
| -------------- | -------------- |
| | **[RouteManager](Classes/classllarp_1_1apple_1_1RouteManager.md#function-routemanager)**(llarp::Context & ctx, llarp_route_callbacks rcs, void * callback_context) |
| virtual void | **[AddRoute](Classes/classllarp_1_1apple_1_1RouteManager.md#function-addroute)**(net::ipaddr_t , net::ipaddr_t ) override<br>These are called for poking route holes, but we don't have to do that at all on macos because the appex isn't subject to its own rules.  |
| virtual void | **[DelRoute](Classes/classllarp_1_1apple_1_1RouteManager.md#function-delroute)**(net::ipaddr_t , net::ipaddr_t ) override |
| virtual void | **[AddDefaultRouteViaInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-adddefaultrouteviainterface)**([vpn::NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn) override |
| virtual void | **[DelDefaultRouteViaInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-deldefaultrouteviainterface)**([vpn::NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn) override |
| virtual void | **[AddRouteViaInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-addrouteviainterface)**([vpn::NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn, [IPRange](Classes/structllarp_1_1IPRange.md) range) override |
| virtual void | **[DelRouteViaInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-delrouteviainterface)**([vpn::NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn, [IPRange](Classes/structllarp_1_1IPRange.md) range) override |
| virtual std::vector< net::ipaddr_t > | **[GetGatewaysNotOnInterface](Classes/classllarp_1_1apple_1_1RouteManager.md#function-getgatewaysnotoninterface)**([vpn::NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & ) override |

## Additional inherited members

**Public Functions inherited from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)**

|                | Name           |
| -------------- | -------------- |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**() =default |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**(const [IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md) & ) =delete |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**([IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md) && ) =delete |
| virtual | **[~IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-~iroutemanager)**() =default |
| virtual const [llarp::net::Platform](Classes/classllarp_1_1net_1_1Platform.md) * | **[Net_ptr](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-net-ptr)**() const |
| const [llarp::net::Platform](Classes/classllarp_1_1net_1_1Platform.md) & | **[Net](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-net)**() const |
| virtual void | **[AddBlackhole](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addblackhole)**() |
| virtual void | **[DelBlackhole](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delblackhole)**() |


## Public Functions Documentation

### function RouteManager

```cpp
inline RouteManager(
    llarp::Context & ctx,
    llarp_route_callbacks rcs,
    void * callback_context
)
```


### function AddRoute

```cpp
inline virtual void AddRoute(
    net::ipaddr_t ,
    net::ipaddr_t 
) override
```

These are called for poking route holes, but we don't have to do that at all on macos because the appex isn't subject to its own rules. 

**Reimplements**: [llarp::vpn::IRouteManager::AddRoute](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addroute)


### function DelRoute

```cpp
inline virtual void DelRoute(
    net::ipaddr_t ,
    net::ipaddr_t 
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelRoute](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delroute)


### function AddDefaultRouteViaInterface

```cpp
virtual void AddDefaultRouteViaInterface(
    vpn::NetworkInterface & vpn
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-adddefaultrouteviainterface)


### function DelDefaultRouteViaInterface

```cpp
virtual void DelDefaultRouteViaInterface(
    vpn::NetworkInterface & vpn
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-deldefaultrouteviainterface)


### function AddRouteViaInterface

```cpp
virtual void AddRouteViaInterface(
    vpn::NetworkInterface & vpn,
    IPRange range
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addrouteviainterface)


### function DelRouteViaInterface

```cpp
virtual void DelRouteViaInterface(
    vpn::NetworkInterface & vpn,
    IPRange range
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delrouteviainterface)


### function GetGatewaysNotOnInterface

```cpp
inline virtual std::vector< net::ipaddr_t > GetGatewaysNotOnInterface(
    vpn::NetworkInterface & 
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::GetGatewaysNotOnInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-getgatewaysnotoninterface)


-------------------------------

Updated on 2022-11-29 at 18:11:26 +0000
